GraphQLTokenType

Enum GraphQLTokenType 

pub enum GraphQLTokenType {
Show 44 variants StringLiteral, IntLiteral, FloatLiteral, BooleanLiteral, NullLiteral, Name, QueryKeyword, MutationKeyword, SubscriptionKeyword, FragmentKeyword, OnKeyword, TypeKeyword, InterfaceKeyword, UnionKeyword, ScalarKeyword, EnumKeyword, InputKeyword, ExtendKeyword, SchemaKeyword, DirectiveKeyword, ImplementsKeyword, RepeatsKeyword, Spread, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Colon, Semicolon, Pipe, Ampersand, Equals, Exclamation, At, Dollar, Whitespace, Comment, SourceFile, Newline, Eof, Error,
}
Token types for GraphQL.

Variants



StringLiteral

A string literal.



IntLiteral

An integer literal.



FloatLiteral

A float literal.



BooleanLiteral

A boolean literal (true or false).



NullLiteral

A null literal (null).



Name

A name (identifier).



QueryKeyword

The query keyword.



MutationKeyword

The mutation keyword.



SubscriptionKeyword

The subscription keyword.



FragmentKeyword

The fragment keyword.



OnKeyword

The on keyword.



TypeKeyword

The type keyword.



InterfaceKeyword

The interface keyword.



UnionKeyword

The union keyword.



ScalarKeyword

The scalar keyword.



EnumKeyword

The enum keyword.



InputKeyword

The input keyword.



ExtendKeyword

The extend keyword.



SchemaKeyword

The schema keyword.



DirectiveKeyword

The directive keyword.



ImplementsKeyword

The implements keyword.



RepeatsKeyword

The repeats keyword.



Spread

The spread operator ....



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



LeftBrace

Left brace {.



RightBrace

Right brace }.



Comma

Comma ,.



Colon

Colon :.



Semicolon

Semicolon ;.



Pipe

Pipe symbol |.



Ampersand

Ampersand symbol &.



Equals

Equals symbol =.



Exclamation

Exclamation mark !.



At

At symbol @.



Dollar

Dollar sign $.



Whitespace

Whitespace.



Comment

A comment.



SourceFile

The root of the source file.



Newline

A newline.



Eof

End of file.



Error

An error token.

Implementations

Source

impl GraphQLTokenType

pub fn is_keyword(&self) -> bool

Returns true if the token type is a keyword.