GraphQLElementType

Enum GraphQLElementType 

pub enum GraphQLElementType {
Show 44 variants StringLiteral, IntLiteral, FloatLiteral, BooleanLiteral, NullLiteral, Name, QueryKeyword, MutationKeyword, SubscriptionKeyword, FragmentKeyword, OnKeyword, TypeKeyword, InterfaceKeyword, UnionKeyword, ScalarKeyword, EnumKeyword, InputKeyword, ExtendKeyword, SchemaKeyword, DirectiveKeyword, ImplementsKeyword, RepeatsKeyword, Spread, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Colon, Semicolon, Pipe, Ampersand, Equals, Exclamation, At, Dollar, Whitespace, Comment, SourceFile, Newline, Eof, Error,
}
Element types for GraphQL.

Variants



StringLiteral

A string literal.



IntLiteral

An integer literal.



FloatLiteral

A float literal.



BooleanLiteral

A boolean literal.



NullLiteral

A null literal.



Name

A name (identifier).



QueryKeyword

The query keyword.



MutationKeyword

The mutation keyword.



SubscriptionKeyword

The subscription keyword.



FragmentKeyword

The fragment keyword.



OnKeyword

The on keyword.



TypeKeyword

The type keyword.



InterfaceKeyword

The interface keyword.



UnionKeyword

The union keyword.



ScalarKeyword

The scalar keyword.



EnumKeyword

The enum keyword.



InputKeyword

The input keyword.



ExtendKeyword

The extend keyword.



SchemaKeyword

The schema keyword.



DirectiveKeyword

The directive keyword.



ImplementsKeyword

The implements keyword.



RepeatsKeyword

The repeatable keyword.



Spread

The spread operator ....



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



LeftBrace

Left brace {.



RightBrace

Right brace }.



Comma

Comma ,.



Colon

Colon :.



Semicolon

Semicolon ;.



Pipe

Pipe |.



Ampersand

Ampersand &.



Equals

Equals =.



Exclamation

Exclamation !.



At

At symbol @.



Dollar

Dollar sign $.



Whitespace

Whitespace.



Comment

A comment.



SourceFile

The root source file.



Newline

A newline.



Eof

End of file.



Error

An error element.

Implementations

Source

impl GraphQLElementType

pub fn is_keyword(&self) -> bool

Returns true if the element type is a keyword.